package org.dvb.gem.companion;

import java.net.InetSocketAddress;

/**
 * Describes {@link CompanionService}'s endpoint.
 */
public interface AppToAppInfo {

  /**
   * Gets protocol name defined as "ApplicationIdentification".GEM.DVB.org_v1,
   * where "ApplicationIdentification" is free text to be supplied by the
   * application vendor.
   *
   * @return Protocol Name defined by application vendor, followed by
   *         ".GEM.DVB.org_v1"
   */
  public String getMatchingProtocolName();

  /**
   * Gets protocol type (for example "REST", "Websocket").
   *
   * @return Protocol type.
   */
  public String getProtocol();

  /**
   * Gets a valid connection address for the protocol type. For protocol defined
   * as "Websocket", it shall be a valid WebSocket address. For protocol defined
   * as "REST", it shall be a valid HTTP or HTTPS address.
   *
   * @return Connection address.
   */
  public InetSocketAddress getConnectionAddress();

  /**
   * Determines if the protocol is required.
   *
   * @return true if protocol is required, false otherwise.
   */
  public boolean isProtocolRequired();

}
