package org.dvb.gem.companion;

/**
 * The interface is an abstract representation of UPnP Application. It provides
 * the data required to control its lifecycle and usage over UPnP Application
 * Management System.
 */
public interface CompanionService {

  /**
   * Starts the service.
   */
  public abstract void start();

  /**
   * Stops the service.
   */
  public abstract void stop();

  /**
   * Pauses the service. When paused, a {@link CompanionService} shall hold on
   * any communication with connected clients.
   */
  public abstract void pause();

  /**
   * Resumes the service from paused state. Communication with clients shall be
   * resumed.
   */
  public abstract void resume();

  /**
   * Gets the name of the service supplied by the service vendor.
   *
   * @return Name of the service.
   */
  public abstract String getFriendlyName();

  /**
   * Gets an arrays of {@link AppToAppInfo} associated with the service. The
   * array shall contain at least one element.
   *
   * @return Array of {@link AppToAppInfo}
   */
  public abstract AppToAppInfo[] getAppToAppInfos();

}
