package org.dvb.gem.companion.rest;

import org.dvb.gem.companion.CompanionService;

/**
 * Represents Companion Service based on REST protocol.
 */
public interface RESTService extends CompanionService {

  /**
   * Realizes GET HTTP request. When the method is called with URI parameter
   * equals to root resource, then the service returns a comma separated list of
   * available resources.
   * 
   * @param resourceURI
   *          URI of a resource to query.
   * @return A value of the resource
   */
  public String GET(String resourceURI);

  /**
   * Realizes POST HTTP request.
   * 
   * @param resourceURI
   *          URI of a resource.
   * @param value
   *          New value of the resource.
   */
  public void POST(String resourceURI, String value);

  /**
   * Realizes PUT HTTP request.
   * 
   * @param resourceURI
   *          URI of a resource.
   * @param value
   *          New value of the resource.
   */
  public void PUT(String resourceURI, String value);

  /**
   * Realizes DELETE HTTP request.
   * 
   * @param resourceURI
   *          URI of a resource to remove.
   */
  public void DELETE(String resourceURI);

}
